@@ -7,9 +7,9 @@ function(x, unique.rm=FALSE, crit=0.05)
     Imor <- numeric(p)
     Imor <- apply(x, 2, function(y) n * ((sum(y^2) - sum(y)) / (sum(y)^2 - sum(y))))
     Smor <- Imor
-    chicr <- qchisq(c(0+crit/2, 1-crit/2), n-1)
-    Muni <- apply(x, 2, function(y) (chicr[1] - n + sum(y)) / (sum(y) - 1))
-    Mclu <- apply(x, 2, function(y) (chicr[2] - n + sum(y)) / (sum(y) - 1))
+    chicr <- qchisq(c(0+crit/2, 1-crit/2), n-1, lower.tail=FALSE)
+    Muni <- apply(x, 2, function(y) (chicr[2] - n + sum(y)) / (sum(y) - 1))
+    Mclu <- apply(x, 2, function(y) (chicr[1] - n + sum(y)) / (sum(y) - 1))
     for (i in 1:p) {
         if (apply(x, 2, sum)[i] > 1) {
             if (Imor[i] >= Mclu[i] && Mclu[i] > 1)
