@@ -32,13 +32,14 @@
     call <- attr(dis, "call")
     call[[1]] <- as.name(distname)
     attr(dis, "call") <- call
-    if (any(dis <= 0)) {
+    if (any(dis <= 0, na.rm = TRUE)) {
         if (zerodist == "fail") 
             stop("Zero dissimilarities are not allowed")
         else if (zerodist == "add") {
-            zero <- min(dis[dis > 0])/2
+            zero <- min(dis[dis > 0], na.rm = TRUE)/2
             dis[dis <= 0] <- zero
-            warning("Zero dissimilarities changed into ", zero)
+            if (trace)
+                cat("Zero dissimilarities changed into ", zero,"\n")
         }
     }
     ## We actually used maxdis to decide whether index has a closed
@@ -50,13 +51,13 @@
     if (noshare > 0 && sum(tmp <- no.shared(comm))/length(dis) > noshare) {
         if (trace) 
             cat("Using step-across dissimilarities:\n")
-        rn <- range(dis[tmp])
+        rn <- range(dis[tmp], na.rm = TRUE)
         if (rn[2]/rn[1] > 1.01)
             warning("non-constant distances between points with nothing shared\n",
                     "  stepacross may be meaningless: consider argument 'noshare=0'")
         is.na(dis) <- tmp
         dis <- stepacross(dis, trace = trace, toolong=0, ...)
-        if (length(unique(distconnected(tmp, trace = trace > 1))) > 1) 
+        if (length(unique(distconnected(tmp, trace = trace))) > 1) 
             warning("Data are disconnected, results may be meaningless")
     }
     attr(dis, "maxdis") <- maxdis
