@@ -1,6 +1,7 @@
 `ordilabel` <-
     function(x, display, labels, choices = c(1,2), priority,
-             cex = 0.8, fill = "white", border = NULL,  ...)
+             cex = 0.8, fill = "white", border = NULL, col = NULL,
+             ...)
 {
     if (missing(display))
         display <- "sites"
@@ -16,10 +17,15 @@
     ex <- strheight("x", cex = cex, ...)
     w <- (strwidth(labels, cex=cex,...) + em/1.5)/2
     h <- (strheight(labels, cex = cex, ...) + ex/1.5)/2
+    if (is.null(col))
+        if (!is.null(border))
+            col <- border
+        else
+            col <- par("fg")
     for (i in 1:nrow(x)) {
         polygon(x[i,1] + c(-1,1,1,-1)*w[i], x[i,2] + c(-1,-1,1,1)*h[i],
                 col = fill, border = border)
-        text(x[i,1], x[i,2], labels = labels[i], cex = cex, ...)
+        text(x[i,1], x[i,2], labels = labels[i], cex = cex, col = col, ...)
     }
     invisible(x)
 }
