@@ -1,7 +1,8 @@
 swan <-
 function (x)
 {
-    while(any(x == 0)) {
+    zeros <- -Inf
+    while(zeros != (zeros <- sum(x == 0)) && any(x == 0)) {
         x[x > 0] <- x[x > 0] - min(x[x > 0]) + 1
         x[x == 0] <- beals(x)[x == 0]
     }
